@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Result;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains the result of a JSON Schema evaluation
 
-our $VERSION = '0.584';
+our $VERSION = '0.585';
 
 use 5.020;
 use Moo;
@@ -262,7 +262,7 @@ JSON::Schema::Modern::Result - Contains the result of a JSON Schema evaluation
 
 =head1 VERSION
 
-version 0.584
+version 0.585
 
 =head1 SYNOPSIS
 
@@ -326,34 +326,19 @@ C<flag> returns just the result of the evaluation: either C<{"valid": true}> or
 
 =item *
 
-C<basic> adds the list of C<errors> or C<annotations> to the boolean evaluation result.
-
-C<instance_location> and C<keyword_location> are always included, as JSON pointers, describing the
-path to the evaluation location; C<absolute_keyword_location> is added (as a resolved URI) whenever
-it is known and different from C<keyword_location>.
+C<basic> adds the list of C<errors> or C<annotations> to the boolean evaluation result. C<instance_location> and C<keyword_location> are always included, as JSON pointers, describing the path to the evaluation location; C<absolute_keyword_location> is added (as a resolved URI) whenever it is known and different from C<keyword_location>.
 
 =item *
 
-C<strict_basic> is like C<basic> but follows the draft-2019-09 specification precisely, including
-
-replicating an error fixed in the next draft, in that C<instance_location> and C<keyword_location>
-values are provided as fragment-only URI references rather than JSON pointers.
+C<strict_basic> is like C<basic> but follows the draft-2019-09 specification precisely, including replicating an error fixed in the next draft, in that C<instance_location> and C<keyword_location> values are provided as fragment-only URI references rather than JSON pointers.
 
 =item *
 
-C<terse> is not described in any specification; it is like C<basic>, but omits some redundant
-
-errors (for example the one for the C<allOf> keyword that is added when any of the subschemas under
-C<allOf> failed evaluation).
+C<terse> is not described in any specification; it is like C<basic>, but omits some redundant errors (for example the one for the C<allOf> keyword that is added when any of the subschemas under C<allOf> failed evaluation).
 
 =item *
 
-C<data_only> returns a string, not a data structure: it contains a list of errors identified only
-
-by their C<instance_location> and error message (or C<keyword_location>, when the error occurred
-while loading the schema itself). This format is suitable for generating errors when the schema is
-not published, or for describing errors with the schema itself. This is not an official
-specification format and may change slightly over time, as it is tested in production environments.
+C<data_only> returns a string, not a data structure: it contains a list of errors identified only by their C<instance_location> and error message (or C<keyword_location>, when the error occurred while loading the schema itself). This format is suitable for generating errors when the schema is not published, or for describing errors with the schema itself. This is not an official specification format and may change slightly over time, as it is tested in production environments.
 
 =back
 
